==> order-base-1.0.20201128.025751-141-sources.jar: com/rocogz/syy/order/dto/pay/CashPayRefundParamDto.java <==
package com.rocogz.syy.order.dto.pay;

import com.rocogz.syy.order.constant.trace.TradeTypeEnum;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;

/**
 * <dl>
 * <dd>Description: 现金支付退款参数Dto</dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2020/7/28 17:42</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
@Accessors(chain = true)
public class CashPayRefundParamDto {

    /**
     * 字段名：订单类型.
     * 是否必填：是
     */
    @NotNull
    private TradeTypeEnum rocoTradeType;

    /**
     * 字段名：微信用户openid.
     * 是否必填：微信支付退款时必填
     */
    private String openid;

    /**
     * <pre>
     * 字段名：支付下单时传入的roco的订单号.
     * 变量名：roco_trade_no
     * 描述：商户侧的订单号
     * </pre>
     */
    @NotEmpty
    private String rocoTradeNo;

    /**
     * <pre>
     * 字段名：roco内部的退款单号.
     * 变量名：roco_refund_no
     * 是否必填：是
     * 类型：String(32)
     * 描述：商户系统内部的退款单号，商户系统内部唯一，同一退款单号多次请求只退一笔
     * </pre>
     */
    @NotEmpty
    private String rocoRefundNo;

    /**
     * <pre>
     * 字段名：退款金额(元).
     * 变量名：refundAmount
     * 是否必填：是
     * </pre>
     */
    @NotNull
    private BigDecimal refundAmount;

    /**
     * <pre>
     * 字段名：退款原因.
     * 变量名：refund_account
     * 是否必填：否
     * 示例值：商品已售完
     * 描述：若商户传入，会在下发给用户的退款消息中体现退款原因
     * </pre>
     */
    private String refundDesc;

    /**
     * <pre>
     * 字段名：退款结果通知url.
     * 变量名：notify_url
     * 是否必填：否
     * 类型：String(256)
     * 示例值：https://weixin.qq.com/notify/
     * 描述：异步接收微信/支付宝支付退款结果通知的回调地址，通知URL必须为外网可访问的url，不允许带参数
     * 如果参数中传了notify_url，则商户平台上配置的回调地址将不会生效。优先级：此处传参 > 项目配置文件配置的 > 商户平台上配置的
     * </pre>
     */
    private String notifyUrl;

    /**
     *  <pre>
     * 字段名：用户编号
     * 是否必填：是
     * 类型：string
     * 示例值：UC202011110001
     * 描述：用户编号
     *  </pre>
     */
    @NotNull
    private String userCode;
}

==> order-base-2.0.20201210.073015-73-sources.jar: com/rocogz/syy/order/dto/pay/CashPayRefundParamDto.java <==
package com.rocogz.syy.order.dto.pay;

import com.rocogz.syy.order.constant.TradeTypeEnum;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;

/**
 * <dl>
 * <dd>Description: 现金支付退款参数Dto</dd>
 * <dd>Company: 大诚若谷信息技术有限公司</dd>
 * <dd>@date：2020/7/28 17:42</dd>
 * <dd>@author：ranxiangfu</dd>
 * </dl>
 */
@Data
@Accessors(chain = true)
public class CashPayRefundParamDto {

    /**
     * 字段名：订单类型.
     * 是否必填：是
     */
    @NotNull
    private TradeTypeEnum rocoTradeType;

    /**
     * 字段名：微信用户openid.
     * 是否必填：微信支付退款时必填
     */
    private String openid;

    /**
     * <pre>
     * 字段名：支付下单时传入的roco的订单号.
     * 变量名：roco_trade_no
     * 描述：商户侧的订单号
     * </pre>
     */
    @NotEmpty
    private String rocoTradeNo;

    /**
     * <pre>
     * 字段名：roco内部的退款单号.
     * 变量名：roco_refund_no
     * 是否必填：是
     * 类型：String(32)
     * 描述：商户系统内部的退款单号，商户系统内部唯一，同一退款单号多次请求只退一笔
     * </pre>
     */
    @NotEmpty
    private String rocoRefundNo;

    /**
     * <pre>
     * 字段名：退款金额(元).
     * 变量名：refundAmount
     * 是否必填：是
     * </pre>
     */
    @NotNull
    private BigDecimal refundAmount;

    /**
     * <pre>
     * 字段名：退款原因.
     * 变量名：refund_account
     * 是否必填：否
     * 示例值：商品已售完
     * 描述：若商户传入，会在下发给用户的退款消息中体现退款原因
     * </pre>
     */
    private String refundDesc;

    /**
     * <pre>
     * 字段名：退款结果通知url.
     * 变量名：notify_url
     * 是否必填：否
     * 类型：String(256)
     * 示例值：https://weixin.qq.com/notify/
     * 描述：异步接收微信/支付宝支付退款结果通知的回调地址，通知URL必须为外网可访问的url，不允许带参数
     * 如果参数中传了notify_url，则商户平台上配置的回调地址将不会生效。优先级：此处传参 > 项目配置文件配置的 > 商户平台上配置的
     * </pre>
     */
    private String notifyUrl;

    /**
     *  <pre>
     * 字段名：用户编号
     * 是否必填：是
     * 类型：string
     * 示例值：UC202011110001
     * 描述：用户编号
     *  </pre>
     */
    @NotNull
    private String userCode;
}
